
package Google::Ads::AdWords::v201109_1::TypeMaps::AdGroupService;
use strict;
use warnings;

our $typemap_1 = {
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201109_1::EntityNotFound::Reason',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutateResponse/rval/value/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DateError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'get/serviceSelector/predicates' => 'Google::Ads::AdWords::v201109_1::Predicate',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201109_1::NotEmptyError::Reason',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]' => 'Google::Ads::AdWords::v201109_1::StatsQueryError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201109_1::RateExceededError::Reason',
               'mutate/operations/operand/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids' => 'Google::Ads::AdWords::v201109_1::AdGroupBids',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/paging' => 'Google::Ads::AdWords::v201109_1::Paging',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]' => 'Google::Ads::AdWords::v201109_1::NewEntityCreationError',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201109_1::AdGroup',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201109_1::AdGroup::Status',
               'mutateResponse/rval/value/bids/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::PercentCPAAdGroupBids',
               'mutateResponse/rval/value/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDeltaStatus',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::BudgetOptimizerAdGroupBids',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::BudgetOptimizerAdGroupBids',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/experimentData' => 'Google::Ads::AdWords::v201109_1::AdGroupExperimentData',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupBids',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/operator' => 'Google::Ads::AdWords::v201109_1::Predicate::Operator',
               'mutateResponse/rval/value/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201109_1::AdGroupExperimentBidMultipliers',
               'Fault/detail/ApiExceptionFault/errors[DateError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201109_1::OperationAccessDenied',
               'getResponse/rval/entries/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DateError]/reason' => 'Google::Ads::AdWords::v201109_1::DateError::Reason',
               'Fault/detail/ApiExceptionFault/errors[BetaError]' => 'Google::Ads::AdWords::v201109_1::BetaError',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]' => 'Google::Ads::AdWords::v201109_1::AdGroupServiceError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201109_1::RateExceededError',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/targetCpa' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats' => 'Google::Ads::AdWords::v201109_1::Stats',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/reason' => 'Google::Ads::AdWords::v201109_1::StatsQueryError::Reason',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::PercentCPAAdGroupBids',
               'getResponse/rval/entries/stats' => 'Google::Ads::AdWords::v201109_1::Stats',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids' => 'Google::Ads::AdWords::v201109_1::AdGroupBids',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/maxCpm/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerAdGroupBids',
               'mutate/operations/operand/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201109_1::DatabaseError::Reason',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[DateError]' => 'Google::Ads::AdWords::v201109_1::DateError',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201109_1::ClientTermsError::Reason',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupBids',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201109_1::InternalApiError',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/maxCpm/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupBids',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/siteMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse' => 'Google::Ads::AdWords::v201109_1::AdGroupService::getResponse',
               'mutateResponse/rval/value/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::BudgetOptimizerAdGroupBids',
               'mutateResponse/rval/value/experimentData' => 'Google::Ads::AdWords::v201109_1::AdGroupExperimentData',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/experimentData' => 'Google::Ads::AdWords::v201109_1::AdGroupExperimentData',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]' => 'Google::Ads::AdWords::v201109_1::BiddingError',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201109_1::AdGroupPage',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201109_1::ClientTermsError',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/percentCpa' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::PercentCPAAdGroupBids',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/maxCpm/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201109_1::AdGroupExperimentBidMultipliers',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201109_1::InternalApiError::Reason',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerAdGroupBids',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201109_1::RejectedError::Reason',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/startDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201109_1::SelectorError::Reason',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'getResponse/rval/entries/bids/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerBidType',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/targetCpa' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201109_1::DatabaseError',
               'mutate/operations/operand/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201109_1::AuthorizationError',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutateResponse/rval/value/bids/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupExperimentBidMultipliers',
               'mutateResponse/rval/value/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutate/operations/operand/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDataStatus',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201109_1::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201109_1::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/costPerConversion/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'mutate/operations/operand/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/percentCpa' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201109_1::AdGroup::Status',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutateResponse/rval/value/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[NewEntityCreationError]/reason' => 'Google::Ads::AdWords::v201109_1::NewEntityCreationError::Reason',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/maxCpm/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpm' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerBidType',
               'getResponse/rval/entries/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[DateError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/deduplicationMode' => 'Google::Ads::AdWords::v201109_1::ConversionDeduplicationMode',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]' => 'Google::Ads::AdWords::v201109_1::QuotaError',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201109_1::ApiException',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupExperimentBidMultipliers',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201109_1::RangeError::Reason',
               'mutate/operations/operand/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError',
               'mutate/operations/operand/bids/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201109_1::RequestError',
               'getResponse/rval/entries/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDataStatus',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201109_1::RequiredError',
               'get/serviceSelector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201109_1::NotEmptyError',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201109_1::AuthenticationError',
               'mutate/operations/operand/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/averageCpc' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDeltaStatus',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/numReceivedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/totalConvValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201109_1::AuthenticationError::Reason',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupBids',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/maxCpm' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/targetCpa' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/Stats.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[StatsQueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/siteMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/averageCpc/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/offlineInteractionCost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse' => 'Google::Ads::AdWords::v201109_1::AdGroupService::mutateResponse',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/maxCpm/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/maxCpm/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/maxCpm/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/reason' => 'Google::Ads::AdWords::v201109_1::OperatorError::Reason',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/maxCpm/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutateResponse/rval/value/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/avgCostForOfflineInteraction/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/campaignId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/stats/ctr' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/conversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/dateRange' => 'Google::Ads::AdWords::v201109_1::DateRange',
               'get/serviceSelector/ordering/sortOrder' => 'Google::Ads::AdWords::v201109_1::SortOrder',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupExperimentBidMultipliers',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupExperimentBidMultipliers',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'get' => 'Google::Ads::AdWords::v201109_1::AdGroupService::get',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/cost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/reason' => 'Google::Ads::AdWords::v201109_1::BetaError::Reason',
               'mutateResponse/rval/value/bids/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201109_1::QuotaCheckError',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/deduplicationMode' => 'Google::Ads::AdWords::v201109_1::ConversionDeduplicationMode',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentDataStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDataStatus',
               'mutateResponse/rval/value/bids/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/numMissedCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/valuePerConvManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/stats/numCalls' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutateResponse/rval/value/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers' => 'Google::Ads::AdWords::v201109_1::AdGroupExperimentBidMultipliers',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'get/serviceSelector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupExperimentBidMultipliers',
               'mutate/operations/operand/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/avgCostForOfflineInteraction/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/offlineInteractionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/bids/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/stats/invalidClicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201109_1::EntityNotFound',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupBids',
               'getResponse/rval/entries/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201109_1::AdGroup::Status',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/campaignName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201109_1::DistinctError::Reason',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/bids' => 'Google::Ads::AdWords::v201109_1::AdGroupBids',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/reason' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError::Reason',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/stats/costPerConversionManyPerClick' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/reason' => 'Google::Ads::AdWords::v201109_1::QuotaError::Reason',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201109_1::NullError',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/offlineInteractionCost' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/conversionOptimizerBidType' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerBidType',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]' => 'Google::Ads::AdWords::v201109_1::ManualCPCAdGroupExperimentBidMultipliers',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/bids/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/cost/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/siteMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/numOfflineInteractions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/costPerConversionManyPerClick/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/maxCpm' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/conversionsManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201109_1::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/stats/averagePosition' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/enhancedCpcEnabled' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/stats/valuePerConv' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/serviceSelector/ordering' => 'Google::Ads::AdWords::v201109_1::OrderBy',
               'getResponse/rval/entries/stats/conversionRateManyPerClick' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/maxCpm/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ManualCPMAdGroupBids',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/percentCpa' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/stats/conversionRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]' => 'Google::Ads::AdWords::v201109_1::NotWhitelistedError',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/avgCallDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/averageCpc/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats' => 'Google::Ads::AdWords::v201109_1::Stats',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201109_1::RequiredError::Reason',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/costPerConversion' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/stats/averageCpm/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'get/serviceSelector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxContentCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201109_1::ReadOnlyError::Reason',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201109_1::NullError::Reason',
               'mutate/operations/operand/experimentData/experimentBidMultipliers/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]' => 'Google::Ads::AdWords::v201109_1::ConversionOptimizerAdGroupBids',
               'getResponse/rval/entries/bids/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[BudgetOptimizerAdGroupBids]/proxySiteMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multiplier' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate' => 'Google::Ads::AdWords::v201109_1::AdGroupService::mutate',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/siteMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/stats/callDurationSecs' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotWhitelistedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/stats/viewThroughConversions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201109_1::ApiError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BiddingError]/reason' => 'Google::Ads::AdWords::v201109_1::BiddingError::Reason',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201109_1::ApiException',
               'getResponse/rval/entries/stats/costPerConversion/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201109_1::SizeLimitError::Reason',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids/interactionBids[PhoneInteractionBid]/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/network' => 'Google::Ads::AdWords::v201109_1::Stats::Network',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentBidMultipliers[ManualCPCAdGroupExperimentBidMultipliers]/maxCpcMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[BetaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201109_1::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201109_1::RequestError::Reason',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/stats/avgCostForOfflineInteraction' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier' => 'Google::Ads::AdWords::v201109_1::BidMultiplier',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordMaxCpc/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/stats/costPerConversionManyPerClick/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/experimentData/experimentId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/stats/offlineInteractionCost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/keywordContentMaxCpc/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/proxyKeywordMaxCpc' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/stats/endDate' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]' => 'Google::Ads::AdWords::v201109_1::PhoneInteractionBid',
               'mutateResponse/rval/value/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/AdGroupBids.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201109_1::AdGroupReturnValue',
               'mutate/operations/operand/stats/averageCpm/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201109_1::OperationAccessDenied::Reason',
               'mutate/operations/operand/stats/numOfflineImpressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount' => 'Google::Ads::AdWords::v201109_1::Bid',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/experimentData/experimentDeltaStatus' => 'Google::Ads::AdWords::v201109_1::ExperimentDeltaStatus',
               'getResponse/rval/entries/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201109_1::AdGroup',
               'mutateResponse/rval/value/stats/cost/microAmount' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/deduplicationMode' => 'Google::Ads::AdWords::v201109_1::ConversionDeduplicationMode',
               'mutate/operations/operand/bids[BudgetOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPMAdGroupBids]/interactionBids/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201109_1::RejectedError',
               'getResponse/rval/entries/bids[ManualCPMAdGroupBids]/interactionBids/minimumBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids/interactionBids' => 'Google::Ads::AdWords::v201109_1::InteractionBid',
               'Fault/detail/ApiExceptionFault/errors[OperatorError]' => 'Google::Ads::AdWords::v201109_1::OperatorError',
               'Fault/detail/ApiExceptionFault/errors[AdGroupServiceError]/reason' => 'Google::Ads::AdWords::v201109_1::AdGroupServiceError::Reason',
               'mutateResponse/rval/value/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/interactionBids/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/maxCpm' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPCAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutateResponse/rval/value/stats/impressions' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/AdGroupExperimentBidMultipliers.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/bids[ManualCPCAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'mutate/operations/operand/bids[PercentCPAAdGroupBids]/interactionBids/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/bids[ManualCPMAdGroupBids]/interactionBids/bidStatus' => 'Google::Ads::AdWords::v201109_1::InteractionBid::BidStatus',
               'getResponse/rval/entries/bids/interactionBids/InteractionBid.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/serviceSelector' => 'Google::Ads::AdWords::v201109_1::Selector',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201109_1::AdGroup',
               'mutate/operations/operand/experimentData/experimentBidMultipliers[ManualCPMAdGroupExperimentBidMultipliers]/maxCpmMultiplier/multipliedBid/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/stats/invalidClickRate' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids[PhoneInteractionBid]/interactionBidAmount/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/id' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/bids[ConversionOptimizerAdGroupBids]/targetCpa/amount/ComparableValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/bids[ConversionOptimizerAdGroupBids]/interactionBids/minimumBid/amount' => 'Google::Ads::AdWords::v201109_1::Money',
               'getResponse/rval/entries/bids[PercentCPAAdGroupBids]/interactionBids[PhoneInteractionBid]/minimumBid' => 'Google::Ads::AdWords::v201109_1::Bid',
               'mutateResponse/rval/value/stats/clicks' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201109_1::SelectorError',
               'mutate/operations' => 'Google::Ads::AdWords::v201109_1::AdGroupOperation'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201109_1::TypeMaps::AdGroupService - typemap for AdGroupService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

